# -*- coding: utf-8 -*-

#############################################################################
#                                                                           #
# Copyright (c) 2008 ISrg (NSI, CEFETCAMPOS, BRAZIL) and Contributors.      #
#                                                    All Rights Reserved.   #
#                                                                           #
# AUTHOR                                                                    # 
#       Leandro Moraes V. Cruz <lmvcruz@gmail.com>                          #
#                                                                           #
# REPORTING BUGS                                                            #
#       Report bugs to <nsi@cefetcampos.br>.                                #
#                                                                           #
# CONTRIBUTORS                                                              #
#       Hugo Lopes Tavares                                                  #
#       Gustavo Rezende                                                     #
#       Fábio Duncan                                                        #
#                                                                           #
#     WARNING: This program as such is intended to be used by professional  #
# programmers who take the whole responsability of assessing all potential  #
# consequences resulting from its eventual inadequacies and bugs            #
# End users who are looking for a ready-to-use solution with commercial     #
# garantees and support are strongly adviced to contract a Free Software    #
# Service Company                                                           #
#                                                                           #
#     This program is Free Software; you can redistribute it and/or         #
# modify it under the terms of the GNU General Public License               #
# as published by the Free Software Foundation; either version 2            #
# of the License, or (at your option) any later version.                    #
#                                                                           #
#     This program is distributed in the hope that it will be useful,       #
# but WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
# GNU General Public License for more details.                              #
#                                                                           #
#     You should have received a copy of the GNU General Public License     #
# along with this program; if not, write to the Free Software               #
# Foundation, Inc., 59 Temple Place - Suite 330, Boston,                    #
# MA  02111-1307, USA.                                                      #
#                                                                           #
#############################################################################

import os
import StringIO

class SvgContent(object):
    """
        TODO
    """
    
    def __init__(self, content_name = "noname", dir_name = "/tmp"):
        """
            TODO
        """    
        self.__NAME = content_name
        
        if(dir_name == '/tmp'):
            self.__DIR = dir_name
        else:
            self.__DIR = os.path.abspath(os.path.join(os.getcwd(),dir_name))
    
    
    def getDirectory(self):
        """
            Return the directory of the file referenced by instance
        """
        return self.__DIR
        
    def setDirectory(self, dir_name):
        """
            Alter attribute __DIR and create new file in other directory, 
            but with equals contents
        """
        if(dir_name == '/tmp'):
            self.__DIR = dir_name
        else:
            self.__DIR = os.path.abspath(os.path.join(os.getcwd(),dir_name))

    # Property to set and get attribute directory of SvgFile 
    directory = property(getDirectory, setDirectory)

    def getName(self):
        """
            Return the name of the file referenced by instance
        """
        return self.__NAME
        
    def setName(self, new_name):
        """
            Alter attribute __NAME and create new file with the new name, 
            but with equals contents
        """
        self.__NAME = new_name
    
    # Property to set and get attribute name of SvgFile    
    name = property(getName, setName)


    def getAbsolutePath(self):
        """
            Return the absolute path of the file referenced by instance.
        """
        return os.path.join(self.__DIR, self.__NAME)
    
    @property
    def content(self):
        """
            TODO
        """
        self._content.seek(0)
        _content = self._content.read()
        
        return _content


class SvgFile(SvgContent):

    """
        A classe SvgFile implementa os metodos referentes a um arquivo.
        
        Atributos:
        __DIR: diretorio onde está armazenado o arquivo
        __NAME: nome do arquivo
        __file: o arquivo ao qual a instancia refere-se
    """

    def __init__(self, filename="noname", dir_name='/tmp'):
        """
            Create a new SvgFile, initializing the the values of self atributes
        """
        super(SvgFile, self).__init__(filename, dir_name)

        super(SvgFile, self).setName(filename)
        super(SvgFile, self).setDirectory(dir_name)
        
        if self.exists():
            self._content = open(super(SvgFile, self).getAbsolutePath(), "a+")
        else:
            self._content = open(super(SvgFile, self).getAbsolutePath(), "w+")

            
    def exists(self, filename=None, directory=None):
        """
            Verify if exists a file, on directory passed by parameter, 
            with name same as filename.
            
        """
        return (filename or super(SvgFile, self).name) in os.listdir(directory or self.directory)


    def setName(self, new_name):
        """
            Alter attribute __NAME and create new file with the new name, 
            but with equals contents
        """
        super(SvgFile, self).setName(new_name)
        self._content = self.deepCopy(super(SvgFile, self).name, self.directory)._content
        
    # Property to set and get attribute name of SvgFile    
    name = property(SvgContent.getName, setName)        
    
        
    def setDirectory(self, new_dir):
        """
            Alter attribute __DIR and create new file in other directory, 
            but with equals contents
        """
        super(SvgFile, self).setDirectory(new_dir)
        self._content = self.deepCopy(super(SvgFile, self).name, self.directory)._content


    # Property to set and get attribute directory of SvgFile 
    directory = property(SvgContent.getDirectory, setDirectory)

    
    def deepCopy(self, filename=None, directory=None):
        """
            Make a copy of the file with other name or in other directory.
        """
        new_file = SvgFile(filename or ("CP_" + super(SvgFile, self).name), directory or self.directory)
        new_file._content = open(new_file.getAbsolutePath(), "a+")
        new_file.setContent(self.content)
        new_file.save()
        return new_file
    
    def setContent(self, content):
        """
            Write a file in file referenced by instance
        """
        self._content.close()
        self._content = open(self.getAbsolutePath(), "w")
        self._content.write(content.encode('utf-8'))
        self._content.close()
        self._content = open(self.getAbsolutePath(), "a+")
    
    def save(self):
        """
            Save the file already open, in atribute self._file, 
            with filename (or self._filename, if parameter filename was None)
        """
        self.setContent(self.content)
    
    def close(self):
        """
            TODO
        """
        self._content.close()


        
class SvgStringIO(SvgContent):
    """
        A classe SvgStringIO, assim como a sua super classe SvgFile
        implementa os metodos referentes a um arquivo. Porém o conteudo
        referenciado pelo file agora é um StringIO.
    """
    
    def __init__(self, filename, content):
        """
            TODO
        """    
        super(SvgStringIO, self).__init__(filename)
        super(SvgStringIO, self).setName(filename)
        self._content = content
        
        self._file = SvgFile(filename)
        content.seek(0)
        c = content.read()
        #print c
        self._file.setContent(c)
        
        
    def setContent(self, content):
        """
            TODO
        """    
        self._content = StringIO.StringIO(content)
        
    """    
    def __del__(self):
        #os.remove("/tmp/"+super(SvgFile, self).name)
        print "/tmp/"+super(SvgFile, self).name
    """        



# -*- coding: utf-8 -*-

#############################################################################
#                                                                           #
# Copyright (c) 2008 ISrg (NSI, CEFETCAMPOS, BRAZIL) and Contributors.      #
#                                                    All Rights Reserved.   #
#                                                                           #
# AUTHOR                                                                    # 
#       Leandro Moraes V. Cruz <lmvcruz@gmail.com>                          #
#                                                                           #
# REPORTING BUGS                                                            #
#       Report bugs to <nsi@cefetcampos.br>.                                #
#                                                                           #
# CONTRIBUTORS                                                              #
#       Hugo Lopes Tavares                                                  #
#       Gustavo Rezende                                                     #
#       Fábio Duncan                                                        #
#                                                                           #
#     WARNING: This program as such is intended to be used by professional  #
# programmers who take the whole responsability of assessing all potential  #
# consequences resulting from its eventual inadequacies and bugs            #
# End users who are looking for a ready-to-use solution with commercial     #
# garantees and support are strongly adviced to contract a Free Software    #
# Service Company                                                           #
#                                                                           #
#     This program is Free Software; you can redistribute it and/or         #
# modify it under the terms of the GNU General Public License               #
# as published by the Free Software Foundation; either version 2            #
# of the License, or (at your option) any later version.                    #
#                                                                           #
#     This program is distributed in the hope that it will be useful,       #
# but WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
# GNU General Public License for more details.                              #
#                                                                           #
#     You should have received a copy of the GNU General Public License     #
# along with this program; if not, write to the Free Software               #
# Foundation, Inc., 59 Temple Place - Suite 330, Boston,                    #
# MA  02111-1307, USA.                                                      #
#                                                                           #
#############################################################################

from xml.dom import minidom

class SvgXmlTool(object):

    """
        A Classe SvgXmlTool apresenta um conjunto de funcionalidades 
        para manipular um código de uma imagem SVG.
        
        Ela utiliza como base, para parsear e manipular codigo svg, 
        a API minidom.
        
        Os métodos apresentados podem ser utilizados em manipulação 
        de outros tipos de codigos xml, porém, pode haver necessidades 
        de extensão, pois sua implementação foi pensada para um codigo 
        SVG.
        
        A descrição das funcionalidades desenvolvidas será apresentada 
        junto ao codigo destas
    """

    def parseXml(self, svg):
        """
            TODO
        """ 
        return minidom.parseString(svg)

    def getCode(self, code):
        """
            TODO
        """        
        return code.toxml()
        
    def copyAttrSvgTag(self, svg_code, new_svg):
        """
            TODO
        """
        attrs = svg_code.documentElement.attributes
        new_attrs = new_svg.documentElement.attributes
        for attr,value in attrs.items():
            new_attrs[attr] = value
        return new_svg

    def copyTag(self, svg_code, new_code, tag_name):
        """
            This method copy all tags, whose name is passed by parameter 
            tag_name, of svg_code to a new_code.
            
            ps: this method verify if new_code has the tag that will be 
            inserted not to repeat.
        """
        doc       = svg_code.documentElement
        newdoc    = new_code.documentElement
        
        tag_list  = doc.getElementsByTagName(tag_name)
        newdoc_tag_id_list = \
              [ elem.getAttribute('id') \
                for elem in newdoc.getElementsByTagName(tag_name)]
                               
        if tag_list:
            for tag in tag_list:
                if not(tag.getAttribute('id') in newdoc_tag_id_list):
                    newchild = svg_code.importNode(tag, True)
                    newdoc.appendChild( newchild )


        return new_code
        


    def getElementNodes(self, node):
        """
            TODO
        """
        return filter( lambda child: \
                       child.nodeType == child.ELEMENT_NODE, node.childNodes )
        
    def getAllChildren(self, node):
        """
            TODO
        """
        xml_tool = SvgXmlTool()
        children = []
        for child in node.childNodes:
            if child.nodeType == child.ELEMENT_NODE:
                children.extend( self.getAllChildren(child) )
        return children + xml_tool.getElementNodes( node )
        
    
    def getElementById(self, node, tag_id):
        """
            This method return a list of elements which each one is
            the parent of the next, the last one is your desired element.
            so, from last to first are your desired element, its parent,
            the parent of its parent, and etc.
            
            Example (I want to find the "x"):
            <svg>
                <g id="v">
                    <path id="no matters"/>
                    <g id="w">
                        <path id="x"/> <!-- WANTED -->
                    </g>
                </g>
            </svg>
            so it returns a list containing [g_v, g_w, path_x].
        """
        if node.nodeType == node.ELEMENT_NODE:
            for child in node.childNodes:
                child_id = child.attributes and child.attributes.get('id')
                if child_id and child_id.value == tag_id:
                    return [child]
                else:
                    elem = self.getElementById(child, tag_id)
                    if elem:
                        return [child] + elem
                        
                        
    def copyListTagById(self, svg, new_svg, tag_id_list):
        """
            This method copy tags listed in parameter tagId
            
            Monta árvores com as listas retornadas por xml_tool.getElementById e
            adiciona cada árvore dentro do nó principal de new_svg (documentElement)
            Exemplo (tag_id_list = ['2', '4']):
            <svg>
                <g id="0">
                    <path id="nao importa"/>
                    <g id="1">
                        <path id="2"/>
                        <path id="nao importa 2"/>
                    </g>
                </g>
                <g id="3.0">
                    <g id="3">
                        <path id="4"/>
                    </g>
                </g>
            </svg>
            xml_tool.getElementById retorna uma lista de listas (uma lista de árvores)
            sendo ELEM_ID o nó xml com a tag igual a ELEM e com id igual a ID:
            [ [(g_0, g_1), (g_1, path_2)], [(g_3.0, g_3), (g_3, path_4)] ]
            uma lista de árvores, pois
            g_0 é pai de g_1 que é pai de path_2 e,
            g_3.0 é pai de g_3 que é pai de path_4.
            
            assim sendo, transforma as sublistas em árovores XML reais
            e coloca-as dentro da raiz de new_svg.
       
        """
        svg_code = svg.getCode()
        new_code = new_svg.getCode()
        list_of_trees = []


        # cria uma lista contendo listas que contém uma árvore linear (os elementos de uma arvore xml)
        for tag in tag_id_list:
            xml_tree = self.getElementById(svg_code.documentElement, tag)
            linear_tree = []
            for elem in xml_tree:
                linear_tree.append(svg_code.importNode(elem, False))
            list_of_trees.append( linear_tree )

        #
        # procura em new_svg algum elemento existente (container), se houver, adiciona dentro dele
        # o elemento desejado
        #
        for tree in list_of_trees:
            desired_elem = tree[-1]
            if self.getElementById(new_code, desired_elem.attributes['id'].value):
                continue
            for pos in range(len(tree)-1, -1, -1):
                elem = tree[pos]
                node = self.getElementById(new_code.documentElement, elem.attributes['id'].value)
                if node:
                    last = node[-1]
                    for index in range(pos+1, len(tree)):
                        last.appendChild(tree[index])
                        last = tree[index]
                    break
            else:
                last = new_code.documentElement
                for child in tree:
                    last.appendChild(child)
                    last = child

        return new_code                           



# -*- coding: utf-8 -*-

#############################################################################
#                                                                           #
# Copyright (c) 2008 ISrg (NSI, CEFETCAMPOS, BRAZIL) and Contributors.      #
#                                                    All Rights Reserved.   #
#                                                                           #
# AUTHOR                                                                    # 
#       Leandro Moraes V. Cruz <lmvcruz@gmail.com>                          #
#                                                                           #
# REPORTING BUGS                                                            #
#       Report bugs to <nsi@cefetcampos.br>.                                #
#                                                                           #
# CONTRIBUTORS                                                              #
#       Hugo Lopes Tavares                                                  #
#       Gustavo Rezende                                                     #
#       Fábio Duncan                                                        #
#                                                                           #
#     WARNING: This program as such is intended to be used by professional  #
# programmers who take the whole responsability of assessing all potential  #
# consequences resulting from its eventual inadequacies and bugs            #
# End users who are looking for a ready-to-use solution with commercial     #
# garantees and support are strongly adviced to contract a Free Software    #
# Service Company                                                           #
#                                                                           #
#     This program is Free Software; you can redistribute it and/or         #
# modify it under the terms of the GNU General Public License               #
# as published by the Free Software Foundation; either version 2            #
# of the License, or (at your option) any later version.                    #
#                                                                           #
#     This program is distributed in the hope that it will be useful,       #
# but WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
# GNU General Public License for more details.                              #
#                                                                           #
#     You should have received a copy of the GNU General Public License     #
# along with this program; if not, write to the Free Software               #
# Foundation, Inc., 59 Temple Place - Suite 330, Boston,                    #
# MA  02111-1307, USA.                                                      #
#                                                                           #
#############################################################################

import os
import string

from nsi.svgtool.SvgImage import SvgImage
from nsi.svgtool.SvgXmlTool import SvgXmlTool
from nsi.svgtool.SvgFile import SvgFile
from nsi.svgtool.SvgFile import SvgStringIO

DIRECTORY_DEFAULT = "/tmp"
ACCEPT_TAG = ['svg','g','rect','circle','path','tspan','text']

class Point:

    def __init__(self, x, y):
        self._x = x
        self._y = y
        
    @property
    def x(self):
        return self._x
 
    @property
    def y(self):
        return self._y 
             
class Box:

    def __init__(self, pointOrigin, width, height):
        """
            TODO
        """
        self._pointOrigin = pointOrigin
        self._width = width
        self._height = height
        self._oppositePoint = Point(float(self._pointOrigin.x) + float(width),
                              float(self._pointOrigin.y) + float(height))

    @property
    def originX(self):
        return self._pointOrigin.x

    @property
    def originY(self):
        return self._pointOrigin.y         

    @property
    def oppositeX(self):
        return self._oppositePoint.x

    @property
    def oppositeY(self):
        return self._oppositePoint.y
    
    def isInside(self, point):
        """
            Return True if the point was inside Bounding Box
        """
        x = (float(self.originX) <= float(point.x) <= float(self.oppositeX))
        y = (float(self.originY) <= float(point.y) <= float(self.oppositeY))
        return x and y
               
               
               
class SvgTool:

    """
        TODO
    """

    def makeNewSvgImage(self, content):
        """
            Return a new svg image
        """
        image = SvgImage(content)        
        return image
    
    def makeNewSvgFile(self, filename="noname", directory="/tmp"):
        """
            Create a new svg image, so return its atribute file
        """    
        return SvgFile(filename, directory)
    
    def makeNewSvgStringIO(self, filename, content=''):
        return SvgStringIO(filename, content)
    
    def copySvgHead(self, svg_code, new_code = None):
        """
            TODO
        """
        xml_tool = SvgXmlTool()
        
        new_code = xml_tool.copyAttrSvgTag(svg_code, \
                                          new_code or self.makeNewSvgImage().getCode())
        new_code = xml_tool.copyTag( svg_code, new_code, 'defs' )
        new_code = xml_tool.copyTag( svg_code, new_code, 'metadata' )
        new_code = xml_tool.copyTag( svg_code, new_code, 'sodipodi:namedview' )
        return new_code
    
    def alterSvgData(self, image, filename = None, directory = None):
        """
            Alter SvgImage's data such filename and directory
        """
        if filename:
            image.alterDataFile(name = filename)
        if directory:
            image.alterDataFile(directory = directory)
        return image

    def __handleTagIdList(self, svg_code, tag_id_list):
        """
            This method should remove all the parent tags whose the 
            children are in tag_id_list.
            So when you have to insert a new child and the parent is not into
            the new SVG Code, the parent should be added as well.
            
            tag_id_list before handled
            ['g1','rect2']
            
            tag_id_list after handled
            ['rect2']
            
            
            Per example:
                <svg>
                  <g id='g1'> <-- Parent
                    <rect id='rect2' /> <-- Child that should be copied to the new SVG Code.
                  </g>
                </svg>
                
                New SVG Code before insertion:
                <svg>
                </svg>
                
                After insertion:
                <svg>
                  <g id='g1'>
                    <rect id='rect2' />
                  </g>
                </svg>
        """
        xml_tool = SvgXmlTool()        
        all_children = xml_tool.getAllChildren(svg_code)
        for tag in all_children:
            if (tag.tagName in ACCEPT_TAG):
                if tag.attributes.get('id').value in tag_id_list:
                    if tag.parentNode.attributes.get('id').value in tag_id_list:
                        tag_id_list.remove( tag.parentNode.attributes['id'].value )
        return tag_id_list

    def isBBoxInRegion(self, box, region):
        """
            This method verify if a box is inside region 
        """
        return region.isInside(box._pointOrigin) and \
               region.isInside(box._oppositePoint)
        
    def generateBoundingBox(self, filename):
        """
            This method return the set of Bounding Box of file, 
            whose name is passed by parameter filename

            The function "inkscape FILE --query-all" is a 
            tuple (id, x, y, w, h)
            
            For Example:
            The inkscape return 
            svg2,25,35,100,150
            
            A Tag, whose id is svg2, has origin in point (25, 35) - 
            x = 25, y = 35 - its width is 100, and height is 150.
        
            This element is splited in a list.
            
            In previous example a list retuned is:
            ['svg2', '25', '35', '100', '150']

            
            TODO: create a method to calculate bounding box of 
            SVG grains whitout inkscape
        """
        bbox_list =  os.popen("inkscape %s --query-all" %(filename))
        bbox_list = map(string.strip, bbox_list.readlines())
        return [item.split(',') for item in bbox_list]

          
    def defineTagsInRegion(self, image, region):
        """
            Return the Ids of the grains within region. If only piece of some
            tag was inside of region concerned, this tag will not considered.
        """
        grainInBB = []
        filename = image._content.getAbsolutePath()
        for line in self.generateBoundingBox(filename):
            pathBBox = line
            box = Box(Point(pathBBox[1],pathBBox[2]),pathBBox[3],pathBBox[4])
            if self.isBBoxInRegion(box, region): 
                    grainInBB.append(pathBBox[0])
        return grainInBB    
    
    def selectGrainsInRegion(self, region, image, new_image):
        """
            Return a new Image with the set of tags which were inside of
            region passed by parameter.
            
            region = {'x', 'y', 'X', 'Y'}, where x,y are the coordinate of the
            top-left vertice and X, Y are the coordinate of the bottom-right 
            vertice of the Rectangle Region define by parameter region.
        """
        tag_id_list = self.defineTagsInRegion(image, region)
        tag_id_list = self.__handleTagIdList(image.getCode(), tag_id_list)
        
        self.copySvgHead(image.getCode(), new_image.getCode())

        xml_tool = SvgXmlTool()
        xml_tool.copyListTagById(image, new_image, tag_id_list)

        new_image.saveSvgImage()        
        
        return new_image

        



# -*- coding: utf-8 -*-

#############################################################################
#                                                                           #
# Copyright (c) 2008 ISrg (NSI, CEFETCAMPOS, BRAZIL) and Contributors.      #
#                                                    All Rights Reserved.   #
#                                                                           #
# AUTHOR                                                                    # 
#       Leandro Moraes V. Cruz <lmvcruz@gmail.com>                          #
#                                                                           #
# REPORTING BUGS                                                            #
#       Report bugs to <nsi@cefetcampos.br>.                                #
#                                                                           #
# CONTRIBUTORS                                                              #
#       Hugo Lopes Tavares                                                  #
#       Gustavo Rezende                                                     #
#       Fábio Duncan                                                        #
#                                                                           #
#     WARNING: This program as such is intended to be used by professional  #
# programmers who take the whole responsability of assessing all potential  #
# consequences resulting from its eventual inadequacies and bugs            #
# End users who are looking for a ready-to-use solution with commercial     #
# garantees and support are strongly adviced to contract a Free Software    #
# Service Company                                                           #
#                                                                           #
#     This program is Free Software; you can redistribute it and/or         #
# modify it under the terms of the GNU General Public License               #
# as published by the Free Software Foundation; either version 2            #
# of the License, or (at your option) any later version.                    #
#                                                                           #
#     This program is distributed in the hope that it will be useful,       #
# but WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
# GNU General Public License for more details.                              #
#                                                                           #
#     You should have received a copy of the GNU General Public License     #
# along with this program; if not, write to the Free Software               #
# Foundation, Inc., 59 Temple Place - Suite 330, Boston,                    #
# MA  02111-1307, USA.                                                      #
#                                                                           #
#############################################################################

from nsi.svgtool.SvgFile import SvgFile
from nsi.svgtool.SvgXmlTool import SvgXmlTool
import os

class SvgImage(object):

    """
        A classe SvgImage implementa um tipo de media abordado por nsi.media:
        imagens SVG (Scalable Vector Graphics).
        
        Atributos:
        __file: uma instancia de um SvgFile. Essa instancia armazena estados
        e comportamentos referentes a um arquivo.
        xml_tool: instancia de um SvgXmlTool (ferramenta para manipular 
        xml - especificamente svg)
        __stringCode: codigo da imagem svg referenciada pela instancia
        __xmlCode: instancia do xml parseado e possivel de ser manipulado 
        pela classe SvgXmlTool
    """
    

    def __init__(self, content):
        """
            This method is the initiator's SvgImage. Its main responsible
            is open the svg content referenced by paramenters.
            If there is the content then open it, else create 
            a new content with basic svg content
        """
        self._content = content
        self.xml_tool = SvgXmlTool()
       
        if (len(self._content.content)==0):
            self._content.setContent(self.xml_tool.getCode(self.xml_tool.parseXml("<svg/>")))
        
        self.updateAttributes()       
         
    def getCode(self):
        """
            Return the xml code of instance (content of content)
        """
        return self.__xmlCode
    
        
    def updateAttributes(self):
        """
            Update the atributtes stringCode and xmlCode with content 
            in content, when this is modify in instance
        """
        self._stringCode = self._content.content
        self.__xmlCode = self.xml_tool.parseXml(self._stringCode)
        
        
    
    def saveSvgImage(self):
        """
            This method write the content of attribute __xmlCode in content 
            referenced by instance of SvgContent (attribute _content)
        """
        self._content.setContent(self.__xmlCode.toxml())

    def alterDataFile(self, name=None, directory=None):
        """
            TODO
        """    
        if name:
            self._content.name = name
        if directory:
            self._content.directory = directory
            
    def getFile(self):
        """
            TODO
        """    
        return self._content
        
    def getContentFile(self):
        """
            TODO
        """    
        return self._content.content
        
    def toPng(self, new_name=None, directory=None):
        """
            This method exports the content of SVG Image for PNG format.
        """
        if not directory:
            directory = self._content.directory
            
        if not new_name:
            new_name = self._content.name[:-3]+'png'
            
        path = os.path.join(directory, new_name)
        
        #print self._content.getAbsolutePath() 
        
        os.popen("inkscape %s --export-png %s" \
                  % (self._content.getAbsolutePath(), path))
